==> haskell-knob-0.1.1-66-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-knob.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 knob
version:              0.1.1
visibility:           public
id:                   knob-0.1.1-3zgK4p10uRFDJQbNgFrr2S
key:                  knob-0.1.1-3zgK4p10uRFDJQbNgFrr2S
license:              MIT
maintainer:           John Millikin <jmillikin@gmail.com>
author:               John Millikin <jmillikin@gmail.com>
stability:            experimental
homepage:             https://john-millikin.com/software/knob/
synopsis:             Memory-backed handles
description:
    Create memory-backed '\''Handle'\''s, referencing virtual files. This is
    mostly useful for testing '\''Handle'\''-based APIs without having to
    interact with the filesystem.

    > import Data.ByteString (pack)
    > import Data.Knob
    > import System.IO
    >
    > main = do
    >     knob <- newKnob (pack [])
    >     h <- newFileHandle knob "test.txt" WriteMode
    >     hPutStrLn h "Hello world!"
    >     hClose h
    >     bytes <- Data.Knob.getContents knob
    >     putStrLn ("Wrote bytes: " ++ show bytes)

category:             System
abi:                  1661ddd7d0e16535c73813c4c23c6755
exposed:              True
exposed-modules:      Data.Knob
import-dirs:          /usr/lib/ghc-9.0.2/site-local/knob-0.1.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/knob-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-knob
hs-libraries:         HSknob-0.1.1-3zgK4p10uRFDJQbNgFrr2S
depends:
    base-4.15.1.0 bytestring-0.10.12.1 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-knob/html/knob.haddock
haddock-html:         /usr/share/doc/haskell-knob/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-knob-0.1.1-67-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-knob.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 knob
version:              0.1.1
visibility:           public
id:                   knob-0.1.1-EOnYI33Xboc4nEOQumHnyH
key:                  knob-0.1.1-EOnYI33Xboc4nEOQumHnyH
license:              MIT
maintainer:           John Millikin <jmillikin@gmail.com>
author:               John Millikin <jmillikin@gmail.com>
stability:            experimental
homepage:             https://john-millikin.com/software/knob/
synopsis:             Memory-backed handles
description:
    Create memory-backed '\''Handle'\''s, referencing virtual files. This is
    mostly useful for testing '\''Handle'\''-based APIs without having to
    interact with the filesystem.

    > import Data.ByteString (pack)
    > import Data.Knob
    > import System.IO
    >
    > main = do
    >     knob <- newKnob (pack [])
    >     h <- newFileHandle knob "test.txt" WriteMode
    >     hPutStrLn h "Hello world!"
    >     hClose h
    >     bytes <- Data.Knob.getContents knob
    >     putStrLn ("Wrote bytes: " ++ show bytes)

category:             System
abi:                  21a7f1071c4b6ac751161acbb2d90866
exposed:              True
exposed-modules:      Data.Knob
import-dirs:          /usr/lib/ghc-9.0.2/site-local/knob-0.1.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/knob-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-knob
hs-libraries:         HSknob-0.1.1-EOnYI33Xboc4nEOQumHnyH
depends:
    base-4.15.1.0 bytestring-0.10.12.1 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-knob/html/knob.haddock
haddock-html:         /usr/share/doc/haskell-knob/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
